@@ -2,6 +2,14 @@ from enum import Enum
 
 from upcloud_api.upcloud_resource import UpCloudResource
 
+STORAGE_OSES_WHICH_REQUIRE_METADATA = [
+    "01000000-0000-4000-8000-000020070100",  # Debian GNU/Linux 12 (Bookworm)
+    "01000000-0000-4000-8000-000030220200",  # Ubuntu Server 22.04 LTS (Jammy Jellyfish)
+    "01000000-0000-4000-8000-000030240200",  # Ubuntu Server 24.04 LTS (Noble Numbat)
+    "01000000-0000-4000-8000-000140020100",  # AlmaLinux 9
+    "01000000-0000-4000-8000-000150020100",  # Rocky Linux 9
+]
+
 
 class BackupDeletionPolicy(Enum):
     """
@@ -21,6 +29,7 @@ class Storage(UpCloudResource):
     ATTRIBUTES = {
         'access': None,
         'address': None,
+        'encrypted': None,
         'labels': None,
         'license': None,
         'state': None,
@@ -55,12 +64,26 @@ class Storage(UpCloudResource):
         elif 'storage_size' in kwargs:
             self.size = kwargs['storage_size']
 
+        if kwargs.get('encrypted') == 'yes':
+            self.encrypted = True
+        else:
+            self.encrypted = False
+
         # send the rest to super._reset
 
         filtered_kwargs = {
             key: val
             for key, val in kwargs.items()
-            if key not in ['uuid', 'storage', 'title', 'storage_title', 'size', 'storage_size']
+            if key
+            not in [
+                'uuid',
+                'storage',
+                'title',
+                'storage_title',
+                'size',
+                'storage_size',
+                'encrypted',
+            ]
         }
         super()._reset(**filtered_kwargs)
 
@@ -153,6 +176,9 @@ class Storage(UpCloudResource):
                 dict_labels.append(label.to_dict())
             body['labels'] = dict_labels
 
+        if hasattr(self, 'encrypted') and isinstance(self.encrypted, bool):
+            body['encrypted'] = "yes" if self.encrypted else "no"
+
         return body
 
     @staticmethod
